@@ -9,14 +9,17 @@ from pycognaize.common.enums import (
     IqFieldKeyEnum,
     IqDataTypesEnum
 )
+from pycognaize.document.html_info import HTML
 from pycognaize.document.page import Page
 from pycognaize.document.field import Field
 from pycognaize.document.tag import ExtractionTag
+from pycognaize.document.tag.html_tag import TDTag
 
 
 class NumericField(Field):
     """Base class for all pycognaize number fields"""
     tag_class: Type[ExtractionTag] = ExtractionTag
+    html_tag_class: Type[TDTag] = TDTag
 
     def __init__(self,
                  name: str,
@@ -44,6 +47,34 @@ class NumericField(Field):
     def value(self):
         return self._value
 
+    @classmethod
+    def construct_from_raw(cls, raw: dict, pages: Dict[int, Page],
+                           html: Optional[HTML] = None) -> 'NumericField':
+        """Create NumericField object from dictionary"""
+        tag_dicts: List[dict] = raw[IqDocumentKeysEnum.tags.value]
+        tags = []
+        for i in tag_dicts:
+            try:
+                if pages:
+                    tags.append(cls.tag_class.construct_from_raw(
+                        raw=i, page=pages[i['page']]))
+                else:
+                    tags.append(cls.html_tag_class.construct_from_raw(
+                        raw=i, html=html))
+            except Exception as e:
+                logging.debug(f"Failed creating tag for field {raw[ID]}: {e}")
+        if pages is None:
+            value = tags[0].value if tags else raw[IqTagKeyEnum.value.value]
+        else:
+            value = raw[IqTagKeyEnum.value.value]
+        return cls(name=raw[IqDocumentKeysEnum.name.value],
+                   value=value,
+                   tags=tags,
+                   field_id=str(raw[ID]),
+                   group_key=raw.get(IqFieldKeyEnum.group_key.value, ''),
+                   group_name=raw.get(IqFieldKeyEnum.group.value, '')
+                   )
+
     @staticmethod
     def convert_to_numeric(value):
         """converts string value to numeric"""
@@ -54,26 +85,6 @@ class NumericField(Field):
             value = float('nan')
         return value
 
-    @classmethod
-    def construct_from_raw(
-            cls, raw: dict, pages: Dict[int, Page]) -> 'NumericField':
-        """Create NumericField object from dictionary"""
-        tag_dicts: List[dict] = raw[IqDocumentKeysEnum.tags.value]
-        tags = []
-        for i in tag_dicts:
-            try:
-                tags.append(cls.tag_class.construct_from_raw(
-                    raw=i, page=pages[i['page']]))
-            except Exception as e:
-                logging.debug(f"Failed creating tag for field {raw[ID]}: {e}")
-        return cls(name=raw[IqDocumentKeysEnum.name.value],
-                   value=raw[IqTagKeyEnum.value.value],
-                   tags=tags,
-                   field_id=str(raw[ID]),
-                   group_key=raw.get(IqFieldKeyEnum.group_key.value, ''),
-                   group_name=raw.get(IqFieldKeyEnum.group.value, '')
-                   )
-
     def to_dict(self) -> dict:
         """Converts NumericField object to dictionary"""
         field_dict = super().to_dict()
